var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { FormListColumnsPickType } from "../..";
import { formSchemaUtil } from "./FormSchemaUtil";
import { mergeDeep } from "./MergeObjects";
export const fetchSchemaFromMap = (schemaMapKey, formItemConfigOverrides, propertyOverrides, dynamicKey) => __awaiter(void 0, void 0, void 0, function* () {
    let schema = yield formSchemaUtil.getSchemaFromMap(schemaMapKey, dynamicKey);
    return mergeSchema(schema, formItemConfigOverrides, propertyOverrides, dynamicKey);
});
export const fetchSchema = (schemaProvider, formItemConfigOverrides, propertyOverrides, dynamicKey) => __awaiter(void 0, void 0, void 0, function* () {
    let schema = yield schemaProvider.getSchema(dynamicKey);
    return mergeSchema(schema, formItemConfigOverrides, propertyOverrides, dynamicKey);
});
export const mergeSchema = (schema, formItemConfigOverrides, propertyOverrides, dynamicKey) => {
    if (schema == null)
        return undefined;
    // merge with overrides
    let merged = mergeDeep(schema === null || schema === void 0 ? void 0 : schema.options, formItemConfigOverrides);
    // property overrides
    let disabledOverrides = propertyOverrides === null || propertyOverrides === void 0 ? void 0 : propertyOverrides.disabledProps;
    let hiddenOverrides = propertyOverrides === null || propertyOverrides === void 0 ? void 0 : propertyOverrides.hiddenProps;
    Object.keys(merged.properties).forEach(_ => {
        if (disabledOverrides != null) {
            let disable = merged.properties[_].disable;
            if (Array.isArray(disabledOverrides)) {
                if (disabledOverrides.indexOf(_) >= 0) {
                    disable = () => true;
                }
            }
            else {
                disable = () => !!disabledOverrides;
            }
            merged.properties[_].disable = disable;
        }
        if (hiddenOverrides != null) {
            const found = hiddenOverrides.columns.indexOf(_) >= 0;
            if (hiddenOverrides.pickType == FormListColumnsPickType.Only) {
                merged.properties[_].hide = () => found;
            }
            else if (hiddenOverrides.pickType == FormListColumnsPickType.Without) {
                merged.properties[_].hide = () => !found;
            }
        }
    });
    schema.options = merged;
    return schema;
};
//# sourceMappingURL=SchemaFetch.js.map